==> release_v1.0.0.tar.gz: exchange-api/xjtu-exchange/src/main/java/com/qmth/xjtu/api/OpenApiController.java <==
package com.qmth.xjtu.api;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.boot.tools.signature.SignatureEntity;
import com.qmth.boot.tools.signature.SignatureType;
import com.qmth.teachcloud.exchange.common.bean.params.OpenParams;
import com.qmth.teachcloud.exchange.common.contant.SystemConstant;
import com.qmth.teachcloud.exchange.common.entity.BasicSchool;
import com.qmth.teachcloud.exchange.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.exchange.common.service.AuthInfoService;
import com.qmth.teachcloud.exchange.common.service.BasicSchoolService;
import com.qmth.teachcloud.exchange.common.service.CommonCacheService;
import com.qmth.teachcloud.exchange.common.service.CommonService;
import com.qmth.teachcloud.exchange.common.util.HttpUtil;
import com.qmth.teachcloud.exchange.common.util.JacksonUtil;
import com.qmth.teachcloud.exchange.common.util.Result;
import com.qmth.teachcloud.exchange.common.util.ServletUtil;
import io.swagger.annotations.*;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpStatus;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.*;

/**
 * <p>
 * 西安交通大学开放接口前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2022-04-26
 */
@Api(tags = "西安交通大学开放接口Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.open}")
@Validated
public class OpenApiController {
    private static final Logger log = LoggerFactory.getLogger(OpenApiController.class);
    private static final String ACCESS_TOKEN_URL = "http://org.xjtu.edu.cn/openplatform/oauth/getAccessToken";
    private static final String USER_INFO_URL = "http://org.xjtu.edu.cn/openplatform/oauth/open/getUserInfo";
    private static final String LOGOUT_URL = "http://org.xjtu.edu.cn/openplatform/oauth/logout";
    private static final String SCHOOL_CODE = "xjtu";//测试学校code，正式改成xjtu
    private static final String LOGIN_BEFORE_XJU_LOGIC_API = "/api/admin/print/open/login_before_xju_logic";//西交大登录之前逻辑

    @Resource
    CommonService commonService;

    @Resource
    AuthInfoService authInfoService;

    @Value("${cas.config.logoutUrl}")
    String logoutUrl;

    @Value("${cas.config.returnUrl}")
    String returnUrl;

    @Value("${cas.config.teachcloudPrintLoginUrl}")
    String teachcloudLoginUrl;

    @Resource
    BasicSchoolService basicSchoolService;

    @Resource
    CommonCacheService commonCacheService;

    @ApiOperation(value = "西安交通大学cas鉴权接口")
    @ApiResponses({@ApiResponse(code = 200, message = "返回消息", response = Result.class)})
    @RequestMapping(value = "/authentication", method = RequestMethod.GET)
    @Aac(auth = BOOL.FALSE)
    public void authentication(@ApiParam(value = "工号") @RequestParam(required = false) String code,
                               @ApiParam(value = "系统参数") @RequestParam(required = false) String state,
                               @ApiParam(value = "用户类型") @RequestParam(required = false) String userType,
                               @ApiParam(value = "员工工号") @RequestParam(required = false) String employeeNo,
                               @ApiParam(value = "返回url") @RequestParam(required = false) String returnUrl) throws IOException {
        if ((Objects.isNull(code) || Objects.equals(code, ""))
                || (Objects.isNull(employeeNo) || Objects.equals(employeeNo, ""))) {
            throw ExceptionResultEnum.ERROR.exception("请先通过学校地址登录");
        }
        authInfoService.appHasExpired(SCHOOL_CODE);

        //2022-12-06加入登录之前逻辑
        if (Objects.isNull(teachcloudLoginUrl) || Objects.equals(teachcloudLoginUrl, "")) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("知学登录跳转地址不存在");
        }
        String[] strs = teachcloudLoginUrl.split(SystemConstant.PATH_SUBSTR);
        if (strs[0].contains(SystemConstant.PATH_MATCH)) {
            strs[0] = strs[0].replace(SystemConstant.PATH_MATCH, SCHOOL_CODE);
        }

        BasicSchool basicSchool = commonCacheService.schoolCache(SCHOOL_CODE);
        Optional.ofNullable(basicSchool).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("学校信息不存在"));

        Long timestamp = System.currentTimeMillis();
        String signature = SignatureEntity.build(SignatureType.SECRET, SystemConstant.METHOD, LOGIN_BEFORE_XJU_LOGIC_API, timestamp, basicSchool.getAccessKey(), basicSchool.getAccessSecret());

        String callResult = HttpUtil.postJson(strs[0] + LOGIN_BEFORE_XJU_LOGIC_API, JacksonUtil.parseJson(employeeNo), signature, timestamp);
        String schoolCode = null;
        if (!StringUtils.isBlank(callResult)) {
            log.info("callbackResult:{}", JacksonUtil.parseJson(callResult));
            Result result = JSON.parseObject(callResult, Result.class);
            if (result.getCode() == HttpStatus.OK.value()) {
                Object data = result.getData();
                List<Map> sysuserList = JSONObject.parseArray(JSON.toJSONString(data), Map.class);
                if (CollectionUtils.isEmpty(sysuserList)) {
                    throw ExceptionResultEnum.ERROR.exception("未查到此用户");
                }
                if (sysuserList.size() >= 2) {
                    throw ExceptionResultEnum.ERROR.exception("查询到有多个用户");
                }
                Long schoolId = Long.parseLong(String.valueOf(sysuserList.get(0).get("schoolId")));
                Optional.ofNullable(schoolId).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("学校id为空"));
                basicSchool = basicSchoolService.getById(schoolId);
                Optional.ofNullable(basicSchool).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("学校id:" + schoolId + ",学校不存在"));
                schoolCode = basicSchool.getCode();
            } else {
                throw ExceptionResultEnum.ERROR.exception("调用知学知考西交大登录前查找账号接口失败");
            }
        }

        Map<String, Object> accessTokenParams = new LinkedHashMap<>();
        accessTokenParams.put("code", code);
        String accessTokenResult = HttpUtil.post(ACCESS_TOKEN_URL, accessTokenParams, null);
        String accessToken = null, gsessionId = null;

        //获取accessToken
        if (Objects.nonNull(accessTokenResult)) {
            log.info("accessTokenResult:{}", JacksonUtil.parseJson(accessTokenResult));
            JSONObject jsonObject = JSONObject.parseObject(accessTokenResult);
            JSONObject object = jsonObject.getJSONObject("data");
            String message = jsonObject.getString("message");
            if (Objects.nonNull(object) && Objects.nonNull(message) && Objects.equals(message, "成功")) {
                accessToken = object.getString("accessToken");
                gsessionId = object.getString("gsessionId");
            } else {
                throw ExceptionResultEnum.ERROR.exception(message);
            }
        }

        OpenParams openParams = null;
        //获取用户信息
        if (Objects.nonNull(accessToken)) {
            String userInfoResult = HttpUtil.post(USER_INFO_URL, null, accessToken);
            if (Objects.nonNull(userInfoResult)) {
                log.info("userInfoResult:{}", JacksonUtil.parseJson(userInfoResult));
                openParams = new OpenParams();
//                openParams.setResult(JacksonUtil.parseJson(userInfoResult));
                JSONObject jsonObject = JSONObject.parseObject(userInfoResult);
                JSONObject object = jsonObject.getJSONObject("data");
                String message = jsonObject.getString("message");
                JSONArray userTypeJsonArray = object.getJSONArray("userTypes");
                JSONArray deptInfoJsonArray = object.getJSONArray("deptInfos");
                if (Objects.nonNull(object) && Objects.nonNull(message) && Objects.equals(message, "成功")) {
                    openParams.setOrgName(object.getString("orgName"));
                    if (Objects.nonNull(userTypeJsonArray) && userTypeJsonArray.size() > 0) {
                        JSONObject userTypeJsonObject = userTypeJsonArray.getJSONObject(0);
                        openParams.setName(userTypeJsonObject.getString("memberName"));
                        Integer userTypeRole = userTypeJsonObject.getInteger("userType");
                        if (Objects.nonNull(userTypeRole) && userTypeRole.intValue() == 1) {
                            openParams.setRoleName("学生");
                        } else if (Objects.nonNull(userTypeRole) && userTypeRole.intValue() == 2) {
                            openParams.setRoleName("教职工");
                        }
                    }
                    if (Objects.nonNull(deptInfoJsonArray) && deptInfoJsonArray.size() > 0) {
                        JSONObject deptInfoJsonArrayJsonObject = deptInfoJsonArray.getJSONObject(0);
                        openParams.setDeptName(deptInfoJsonArrayJsonObject.getString("deptName"));
                    }
                } else {
                    throw ExceptionResultEnum.ERROR.exception(message);
                }
            }
        }

        //登出
        if (Objects.nonNull(gsessionId)) {
            StringJoiner stringJoiner = new StringJoiner("");
            stringJoiner.add(logoutUrl).add(SystemConstant.GET_UNKNOWN).add("gSessionId")
                    .add(SystemConstant.GET_EQUAL).add(gsessionId);
            returnUrl = stringJoiner.toString();
        } else {
            throw ExceptionResultEnum.ERROR.exception("gSessionId为空");
        }

        commonService.redirectLogic(employeeNo, schoolCode, returnUrl, Objects.nonNull(openParams) ? JacksonUtil.parseJson(openParams) : null);
    }

    @ApiOperation(value = "西安交通大学cas鉴权退出接口")
    @RequestMapping(value = "/authentication/logout", method = RequestMethod.GET)
    @ApiResponses({@ApiResponse(code = 200, message = "返回消息", response = Result.class)})
    @Aac(auth = BOOL.FALSE)
    public void logout(@ApiParam(value = "sessionId", required = true) @RequestParam String gSessionId) throws IOException {
        if (Objects.isNull(logoutUrl) || Objects.equals(logoutUrl, "")) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("鉴权退出地址不存在");
        }
        if (Objects.isNull(gSessionId) || Objects.equals(gSessionId, "")) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("sessionId为空");
        }
        authInfoService.appHasExpired(SCHOOL_CODE);
        Map<String, Object> logoutParams = new LinkedHashMap<>();
        logoutParams.put("gSessionId", gSessionId);
        String logoutResult = HttpUtil.post(LOGOUT_URL, logoutParams, null);
        if (Objects.nonNull(logoutResult)) {
            log.info("logoutResult:{}", JacksonUtil.parseJson(logoutResult));
            JSONObject jsonObject = JSONObject.parseObject(logoutResult);
            String message = jsonObject.getString("message");
            if (Objects.nonNull(message) && Objects.equals(message, "成功")) {
                HttpServletResponse response = ServletUtil.getResponse();
                response.setHeader("Access-Control-Allow-Origin", SystemConstant.PATH_MATCH);
                response.sendRedirect(returnUrl);
            }
        }
    }
}

==> release_v1.0.1.tar.gz: exchange-api/xjtu-exchange/src/main/java/com/qmth/xjtu/api/OpenApiController.java <==
package com.qmth.xjtu.api;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.boot.tools.signature.SignatureEntity;
import com.qmth.boot.tools.signature.SignatureType;
import com.qmth.teachcloud.exchange.common.bean.params.OpenParams;
import com.qmth.teachcloud.exchange.common.contant.SystemConstant;
import com.qmth.teachcloud.exchange.common.entity.BasicSchool;
import com.qmth.teachcloud.exchange.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.exchange.common.service.AuthInfoService;
import com.qmth.teachcloud.exchange.common.service.BasicSchoolService;
import com.qmth.teachcloud.exchange.common.service.CommonService;
import com.qmth.teachcloud.exchange.common.util.HttpUtil;
import com.qmth.teachcloud.exchange.common.util.JacksonUtil;
import com.qmth.teachcloud.exchange.common.util.Result;
import com.qmth.teachcloud.exchange.common.util.ServletUtil;
import io.swagger.annotations.*;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpStatus;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.*;

/**
 * <p>
 * 西安交通大学开放接口前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2022-04-26
 */
@Api(tags = "西安交通大学开放接口Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_OPEN)
@Validated
public class OpenApiController {
    private static final Logger log = LoggerFactory.getLogger(OpenApiController.class);
    private static final String ACCESS_TOKEN_URL = "http://org.xjtu.edu.cn/openplatform/oauth/getAccessToken";
    private static final String USER_INFO_URL = "http://org.xjtu.edu.cn/openplatform/oauth/open/getUserInfo";
    private static final String LOGOUT_URL = "http://org.xjtu.edu.cn/openplatform/oauth/logout";
    private static final String SCHOOL_CODE = "xjtu";//测试学校code，正式改成xjtu
    private static final String LOGIN_BEFORE_XJU_LOGIC_API = "/api/admin/print/open/login_before_xju_logic";//西交大登录之前逻辑
    private static final String VERSION = "1.0.1.1";

    @Resource
    CommonService commonService;

    @Resource
    AuthInfoService authInfoService;

    @Value("${cas.config.logoutUrl}")
    String logoutUrl;

    @Value("${cas.config.returnUrl}")
    String returnUrl;

    @Value("${cas.config.teachcloudPrintLoginUrl}")
    String teachcloudLoginUrl;

    @Resource
    BasicSchoolService basicSchoolService;

    @ApiOperation(value = "西安交通大学cas鉴权接口")
    @ApiResponses({@ApiResponse(code = 200, message = "返回消息", response = Result.class)})
    @RequestMapping(value = "/authentication", method = RequestMethod.GET)
    @Aac(auth = BOOL.FALSE)
    public void authentication(@ApiParam(value = "工号") @RequestParam(required = false) String code,
                               @ApiParam(value = "系统参数") @RequestParam(required = false) String state,
                               @ApiParam(value = "用户类型") @RequestParam(required = false) String userType,
                               @ApiParam(value = "员工工号") @RequestParam(required = false) String employeeNo,
                               @ApiParam(value = "返回url") @RequestParam(required = false) String returnUrl) throws IOException {
        log.info("version:{}", VERSION);
        if ((Objects.isNull(code) || Objects.equals(code, ""))
                || (Objects.isNull(employeeNo) || Objects.equals(employeeNo, ""))) {
            throw ExceptionResultEnum.ERROR.exception("请先通过学校地址登录");
        }
        authInfoService.appHasExpired(SCHOOL_CODE);

        //2022-12-06加入登录之前逻辑
        if (Objects.isNull(teachcloudLoginUrl) || Objects.equals(teachcloudLoginUrl, "")) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("知学登录跳转地址不存在");
        }
        String[] strs = teachcloudLoginUrl.split(SystemConstant.PATH_SUBSTR);
        if (strs[0].contains(SystemConstant.PATH_MATCH)) {
            strs[0] = strs[0].replace(SystemConstant.PATH_MATCH, SCHOOL_CODE);
        }

        QueryWrapper<BasicSchool> basicSchoolQueryWrapper = new QueryWrapper<>();
        basicSchoolQueryWrapper.lambda().eq(BasicSchool::getCode, SCHOOL_CODE);
        BasicSchool basicSchool = basicSchoolService.getOne(basicSchoolQueryWrapper);
        Optional.ofNullable(basicSchool).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("学校信息不存在"));

        Long timestamp = System.currentTimeMillis();
        String signature = SignatureEntity.build(SignatureType.SECRET, SystemConstant.METHOD, LOGIN_BEFORE_XJU_LOGIC_API, timestamp, basicSchool.getAccessKey(), basicSchool.getAccessSecret());

        String callResult = HttpUtil.postJson(strs[0] + LOGIN_BEFORE_XJU_LOGIC_API, JacksonUtil.parseJson(employeeNo), signature, timestamp);
//        String schoolCodeParam = null;
        if (!StringUtils.isBlank(callResult)) {
            log.info("callbackResult:{}", JacksonUtil.parseJson(callResult));
            Result result = JSON.parseObject(callResult, Result.class);
            if (result.getCode() == HttpStatus.OK.value()) {
                Object data = result.getData();
                List<Map> sysuserList = JSONObject.parseArray(JSON.toJSONString(data), Map.class);
                if (CollectionUtils.isEmpty(sysuserList)) {
                    throw ExceptionResultEnum.ERROR.exception("未查到此用户");
                }
//                if (sysuserList.size() >= 2) {
//                    throw ExceptionResultEnum.ERROR.exception("查询到有多个用户");
//                }
//                String schoolId = String.valueOf(sysuserList.get(0).get("schoolId"));
//                Optional.ofNullable(schoolId).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("学校id为空"));
//                BasicSchool basicSchoolMap = (BasicSchool) cacheService.get(SystemConstant.SCHOOL_CACHE, schoolId);
//                Optional.ofNullable(basicSchoolMap).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("学校id:" + schoolId + ",学校不存在"));
//                schoolCodeParam = basicSchoolMap.getCode();
            } else {
                throw ExceptionResultEnum.ERROR.exception("调用知学知考西交大登录前查找账号接口失败");
            }
        }

        Map<String, Object> accessTokenParams = new LinkedHashMap<>();
        accessTokenParams.put("code", code);
        String accessTokenResult = HttpUtil.post(ACCESS_TOKEN_URL, accessTokenParams, null);
        String accessToken = null, gsessionId = null;

        //获取accessToken
        if (Objects.nonNull(accessTokenResult)) {
            log.info("accessTokenResult:{}", JacksonUtil.parseJson(accessTokenResult));
            JSONObject jsonObject = JSONObject.parseObject(accessTokenResult);
            JSONObject object = jsonObject.getJSONObject("data");
            String message = jsonObject.getString("message");
            if (Objects.nonNull(object) && Objects.nonNull(message) && Objects.equals(message, "成功")) {
                accessToken = object.getString("accessToken");
                gsessionId = object.getString("gsessionId");
            } else {
                throw ExceptionResultEnum.ERROR.exception(message);
            }
        }

        OpenParams openParams = null;
        //获取用户信息
        if (Objects.nonNull(accessToken)) {
            String userInfoResult = HttpUtil.post(USER_INFO_URL, null, accessToken);
            if (Objects.nonNull(userInfoResult)) {
                log.info("userInfoResult:{}", JacksonUtil.parseJson(userInfoResult));
                openParams = new OpenParams();
//                openParams.setResult(JacksonUtil.parseJson(userInfoResult));
                JSONObject jsonObject = JSONObject.parseObject(userInfoResult);
                JSONObject object = jsonObject.getJSONObject("data");
                String message = jsonObject.getString("message");
                JSONArray userTypeJsonArray = object.getJSONArray("userTypes");
                JSONArray deptInfoJsonArray = object.getJSONArray("deptInfos");
                if (Objects.nonNull(object) && Objects.nonNull(message) && Objects.equals(message, "成功")) {
                    openParams.setOrgName(object.getString("orgName"));
                    if (Objects.nonNull(userTypeJsonArray) && userTypeJsonArray.size() > 0) {
                        JSONObject userTypeJsonObject = userTypeJsonArray.getJSONObject(0);
                        openParams.setName(userTypeJsonObject.getString("memberName"));
                        Integer userTypeRole = userTypeJsonObject.getInteger("userType");
                        if (Objects.nonNull(userTypeRole) && userTypeRole.intValue() == 1) {
                            openParams.setRoleName("学生");
                        } else if (Objects.nonNull(userTypeRole) && userTypeRole.intValue() == 2) {
                            openParams.setRoleName("教职工");
                        }
                    }
                    if (Objects.nonNull(deptInfoJsonArray) && deptInfoJsonArray.size() > 0) {
                        JSONObject deptInfoJsonArrayJsonObject = deptInfoJsonArray.getJSONObject(0);
                        openParams.setDeptName(deptInfoJsonArrayJsonObject.getString("deptName"));
                    }
                } else {
                    throw ExceptionResultEnum.ERROR.exception(message);
                }
            }
        }

        //登出
        if (Objects.nonNull(gsessionId)) {
            StringJoiner stringJoiner = new StringJoiner("");
            stringJoiner.add(logoutUrl).add(SystemConstant.GET_UNKNOWN).add("gSessionId")
                    .add(SystemConstant.GET_EQUAL).add(gsessionId);
            returnUrl = stringJoiner.toString();
        } else {
            throw ExceptionResultEnum.ERROR.exception("gSessionId为空");
        }

        commonService.redirectLogic(employeeNo, SCHOOL_CODE, returnUrl, Objects.nonNull(openParams) ? JacksonUtil.parseJson(openParams) : null);
    }

    @ApiOperation(value = "西安交通大学cas鉴权退出接口")
    @RequestMapping(value = "/authentication/logout", method = RequestMethod.GET)
    @ApiResponses({@ApiResponse(code = 200, message = "返回消息", response = Result.class)})
    @Aac(auth = BOOL.FALSE)
    public void logout(@ApiParam(value = "sessionId", required = true) @RequestParam String gSessionId) throws IOException {
        if (Objects.isNull(logoutUrl) || Objects.equals(logoutUrl, "")) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("鉴权退出地址不存在");
        }
        if (Objects.isNull(gSessionId) || Objects.equals(gSessionId, "")) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception("sessionId为空");
        }
        authInfoService.appHasExpired(SCHOOL_CODE);
        Map<String, Object> logoutParams = new LinkedHashMap<>();
        logoutParams.put("gSessionId", gSessionId);
        String logoutResult = HttpUtil.post(LOGOUT_URL, logoutParams, null);
        if (Objects.nonNull(logoutResult)) {
            log.info("logoutResult:{}", JacksonUtil.parseJson(logoutResult));
            JSONObject jsonObject = JSONObject.parseObject(logoutResult);
            String message = jsonObject.getString("message");
            if (Objects.nonNull(message) && Objects.equals(message, "成功")) {
                HttpServletResponse response = ServletUtil.getResponse();
                response.setHeader("Access-Control-Allow-Origin", SystemConstant.PATH_MATCH);
                response.sendRedirect(returnUrl);
            }
        }
    }
}
